@@ -21,8 +21,8 @@
 # SOFTWARE.
 from typing import Optional
 
-from squeak.core.signing import SqueakPrivateKey
-from squeak.core.signing import SqueakPublicKey
+from squeak.core.keys import SqueakPrivateKey
+from squeak.core.keys import SqueakPublicKey
 
 from squeaknode.core.squeak_profile import SqueakProfile
 
